High-Level Models
===============================

Ready-to-use concept-based models with automatic or manual training support.

.. currentmodule:: torch_concepts.nn

Summary
-------

**Model Classes**

.. autosummary::
   :toctree: generated
   :nosignatures:

   ConceptBottleneckModel
   ConceptBottleneckModel_Joint
   BlackBox


Class Documentation
-------------------

.. autoclass:: ConceptBottleneckModel
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: ConceptBottleneckModel_Joint
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: BlackBox
   :members:
   :undoc-members:
   :show-inheritance:
